DOMObject

Struct DOMObject 

pub struct DOMObject { /* private fields */ }
👎Deprecated
Available on crate features DOMObject and WebScriptObject only.
Implementations

Source

impl DOMObject

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

👎Deprecated
Source

impl DOMObject

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Source

impl DOMObject

DOMLinkStyle.

pub unsafe fn sheet(&self) -> Option<Retained<DOMStyleSheet>>

👎Deprecated
Available on crate feature DOMStyleSheet only.

Methods from Deref<Target = WebScriptObject>

pub unsafe fn JSObject(&self) -> JSObjectRef

Available on crate feature objc2-javascript-core only.

Returns: The equivalent JSObjectRef for this WebScriptObject.

Use this method to bridge between the WebScriptObject and JavaScriptCore APIs.

pub unsafe fn callWebScriptMethod_withArguments( &self, name: Option<&NSString>, arguments: Option<&NSArray>, ) -> Option<Retained<AnyObject>>

👎Deprecated

Parameter name: The name of the method to call in the script environment.

Parameter arguments: The arguments to pass to the script environment.

Calls the specified method in the script environment using the specified arguments.

Returns: Returns the result of calling the script method. Returns WebUndefined when an exception is thrown in the script environment.

Safety
  • name might not allow None.
  • arguments generic should be of the correct type.
  • arguments might not allow None.
pub unsafe fn evaluateWebScript( &self, script: Option<&NSString>, ) -> Option<Retained<AnyObject>>

👎Deprecated

Parameter script: The script to execute in the target script environment.

The script will be executed in the target script environment. The format of the script is dependent of the target script environment.

Returns: Returns the result of evaluating the script in the script environment. Returns WebUndefined when an exception is thrown in the script environment.

Safety

script might not allow None.

pub unsafe fn removeWebScriptKey(&self, name: Option<&NSString>)

👎Deprecated

Parameter name: The name of the property to remove.

Removes the property from the object in the script environment.

Safety

name might not allow None.

pub unsafe fn stringRepresentation(&self) -> Option<Retained<NSString>>

👎Deprecated

Converts the target object to a string representation. The coercion of non string objects type is dependent on the script environment.

Returns: Returns the string representation of the object.

pub unsafe fn webScriptValueAtIndex( &self, index: c_uint, ) -> Option<Retained<AnyObject>>

👎Deprecated

Parameter index: The index of the property to return.

Gets the value of the property at the specified index.

Returns: The value of the property. Returns WebUndefined when an exception is thrown in the script environment.

pub unsafe fn setWebScriptValueAtIndex_value( &self, index: c_uint, value: Option<&AnyObject>, )

👎Deprecated

Parameter index: The index of the property to set.

Parameter value: The value of the property to set.

Sets the property value at the specified index.

Safety
  • value should be of the correct type.
  • value might not allow None.
pub unsafe fn setException(&self, description: Option<&NSString>)

👎Deprecated

Parameter description: The description of the exception.

Raises an exception in the script environment in the context of the current object.

Safety

description might not allow None.

pub unsafe fn JSValue(&self) -> Option<Retained<JSValue>>

👎Deprecated
Available on crate feature objc2-javascript-core only.

Returns: The equivalent Objective-C JSValue for this WebScriptObject.

Use this method to bridge between the WebScriptObject and JavaScriptCore Objective-C APIs.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated:

this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}