WKScriptMessageHandler

Trait WKScriptMessageHandler 

pub unsafe trait WKScriptMessageHandler: NSObjectProtocol + MainThreadOnly {
    // Provided method
    unsafe fn userContentController_didReceiveScriptMessage(
        &self,
        user_content_controller: &WKUserContentController,
        message: &WKScriptMessage,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature WKScriptMessageHandler only.
A class conforming to the WKScriptMessageHandler protocol provides a method for receiving messages from JavaScript running in a webpage.

See also Apple’s documentation

Provided Methods

unsafe fn userContentController_didReceiveScriptMessage( &self, user_content_controller: &WKUserContentController, message: &WKScriptMessage, )
where Self: Sized + Message,

Available on crate features WKScriptMessage and WKUserContentController only.

Invoked when a script message is received from a webpage.

Parameter userContentController: The user content controller invoking the delegate method.

Parameter message: The script message received.