pub unsafe trait WebFrameLoadDelegate: NSObjectProtocol { }👎Deprecated
Available on crate feature
WebFrameLoadDelegate only.Expand description
A WebView’s WebFrameLoadDelegate tracks the loading progress of its frames. When a data source of a frame starts to load, the data source is considered “provisional”. Once at least one byte is received, the data source is considered “committed”. This is done so the contents of the frame will not be lost if the new data source fails to successfully load.
See also Apple’s documentation