WebOpenPanelResultListener

Trait WebOpenPanelResultListener 

pub unsafe trait WebOpenPanelResultListener: NSObjectProtocol {
    // Provided methods
    unsafe fn chooseFilename(&self, file_name: Option<&NSString>)
       where Self: Sized + Message { ... }
    unsafe fn chooseFilenames(&self, file_names: Option<&NSArray>)
       where Self: Sized + Message { ... }
    unsafe fn cancel(&self)
       where Self: Sized + Message { ... }
}
👎Deprecated
Available on crate feature WebUIDelegate only.
This protocol is used to call back with the results of the file open panel requested by runOpenPanelForFileButtonWithResultListener:

See also Apple’s documentation

Provided Methods

unsafe fn chooseFilename(&self, file_name: Option<&NSString>)
where Self: Sized + Message,

👎Deprecated

Call this method to return a filename from the file open panel.

Parameter fileName: the path of the selected file

Safety

file_name might not allow None.

unsafe fn chooseFilenames(&self, file_names: Option<&NSArray>)
where Self: Sized + Message,

👎Deprecated

Call this method to return an array of filenames from the file open panel.

Parameter fileNames: an array of paths of selected files

Safety
  • file_names generic should be of the correct type.
  • file_names might not allow None.
unsafe fn cancel(&self)
where Self: Sized + Message,

👎Deprecated

Call this method to indicate that the file open panel was cancelled.