pub unsafe trait WebUIDelegate: NSObjectProtocol { }👎Deprecated
Available on crate feature
WebUIDelegate only.Expand description
A class that implements WebUIDelegate provides window-related methods that may be used by Javascript, plugins and other aspects of web pages. These methods are used to open new windows and control aspects of existing windows.
See also Apple’s documentation