pub type NSAttributedStringCompletionHandler = *mut DynBlock<dyn Fn(*mut NSAttributedString, *mut NSDictionary<NSAttributedStringDocumentAttributeKey, AnyObject>, *mut NSError)>;Available on macOS and crate feature
block2 and crate feature NSAttributedString and crate feature objc2-app-kit only.Expand description
Type definition for the completion handler block used to get asynchronous attributed strings.
The completion handler block is passed the attributed string result along with any document-level attributes, like NSBackgroundColorDocumentAttribute, or an error. An implementation of this block type must expect to be called asynchronously when passed to HTML loading methods.
See also Appleās documentation