WebDownloadDelegate

Trait WebDownloadDelegate 

pub unsafe trait WebDownloadDelegate: NSURLDownloadDelegate {
    // Provided method
    unsafe fn downloadWindowForAuthenticationSheet(
        &self,
        download: Option<&WebDownload>,
        mtm: MainThreadMarker,
    ) -> Option<Retained<NSWindow>>
       where Self: Sized + Message { ... }
}
👎Deprecated
Available on crate feature WebDownload only.
The WebDownloadDelegate delegate has one extra method used to choose the right window when automatically prompting with a sheet.

See also Apple’s documentation

Provided Methods

unsafe fn downloadWindowForAuthenticationSheet( &self, download: Option<&WebDownload>, mtm: MainThreadMarker, ) -> Option<Retained<NSWindow>>
where Self: Sized + Message,

👎Deprecated
Available on macOS and crate feature objc2-app-kit only.
Safety

download might not allow None.