pub unsafe trait WebDownloadDelegate: NSURLDownloadDelegate {
// Provided method
unsafe fn downloadWindowForAuthenticationSheet(
&self,
download: Option<&WebDownload>,
mtm: MainThreadMarker,
) -> Option<Retained<NSWindow>>
where Self: Sized + Message { ... }
}👎Deprecated
Available on crate feature
WebDownload only.Expand description
The WebDownloadDelegate delegate has one extra method used to choose the right window when automatically prompting with a sheet.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn downloadWindowForAuthenticationSheet(
&self,
download: Option<&WebDownload>,
mtm: MainThreadMarker,
) -> Option<Retained<NSWindow>>
👎DeprecatedAvailable on macOS and crate feature objc2-app-kit only.
unsafe fn downloadWindowForAuthenticationSheet( &self, download: Option<&WebDownload>, mtm: MainThreadMarker, ) -> Option<Retained<NSWindow>>
objc2-app-kit only.Safety
download might not allow None.