pub unsafe trait WebDownloadDelegate: NSURLDownloadDelegate { }👎Deprecated
Available on crate feature
WebDownload only.Expand description
The WebDownloadDelegate delegate has one extra method used to choose the right window when automatically prompting with a sheet.
See also Apple’s documentation